==> kserve-0.7.0rc0.tar.gz: kserve-0.7.0rc0/kserve/__init__.py <==
# Copyright 2020 kubeflow.org.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
from __future__ import absolute_import

from kserve.kfmodel import KFModel
from kserve.kfserver import KFServer
from kserve.storage import Storage
from kserve.constants import constants
from kserve.utils import utils
from kserve.handlers import http

# import client apis into kfserving package
from kserve.api.kf_serving_client import KServeClient
from kserve.constants import constants

# import ApiClient
from kserve.api_client import ApiClient
from kserve.configuration import Configuration
from kserve.exceptions import OpenApiException
from kserve.exceptions import ApiTypeError
from kserve.exceptions import ApiValueError
from kserve.exceptions import ApiKeyError
from kserve.exceptions import ApiException

# import v1alpha1 models into kfserving packages
from kserve.models.v1alpha1_model_spec import V1alpha1ModelSpec
from kserve.models.v1alpha1_trained_model import V1alpha1TrainedModel
from kserve.models.v1alpha1_trained_model_list import V1alpha1TrainedModelList
from kserve.models.v1alpha1_trained_model_spec import V1alpha1TrainedModelSpec

# import v1alpha2 models into kfserving package
from kserve.models.knative_addressable import KnativeAddressable
from kserve.models.knative_condition import KnativeCondition
from kserve.models.knative_url import KnativeURL
from kserve.models.knative_volatile_time import KnativeVolatileTime
from kserve.models.net_url_userinfo import NetUrlUserinfo
from kserve.models.v1alpha2_alibi_explainer_spec import V1alpha2AlibiExplainerSpec
from kserve.models.v1alpha2_aix_explainer_spec import V1alpha2AIXExplainerSpec
from kserve.models.v1alpha2_batcher import V1alpha2Batcher
from kserve.models.v1alpha2_custom_spec import V1alpha2CustomSpec
from kserve.models.v1alpha2_inference_service import V1alpha2InferenceService
from kserve.models.v1alpha2_inference_service_list import V1alpha2InferenceServiceList
from kserve.models.v1alpha2_inference_service_spec import V1alpha2InferenceServiceSpec
from kserve.models.v1alpha2_inference_service_status import V1alpha2InferenceServiceStatus
from kserve.models.v1alpha2_endpoint_spec import V1alpha2EndpointSpec
from kserve.models.v1alpha2_predictor_spec import V1alpha2PredictorSpec
from kserve.models.v1alpha2_transformer_spec import V1alpha2TransformerSpec
from kserve.models.v1alpha2_explainer_spec import V1alpha2ExplainerSpec
from kserve.models.v1alpha2_py_torch_spec import V1alpha2PyTorchSpec
from kserve.models.v1alpha2_sk_learn_spec import V1alpha2SKLearnSpec
from kserve.models.v1alpha2_pmml_spec import V1alpha2PMMLSpec
from kserve.models.v1alpha2_logger import V1alpha2Logger
from kserve.models.v1alpha2_onnx_spec import V1alpha2ONNXSpec
from kserve.models.v1alpha2_status_configuration_spec import V1alpha2StatusConfigurationSpec
from kserve.models.v1alpha2_triton_spec import V1alpha2TritonSpec
from kserve.models.v1alpha2_tensorflow_spec import V1alpha2TensorflowSpec
from kserve.models.v1alpha2_xg_boost_spec import V1alpha2XGBoostSpec
from kserve.models.v1alpha2_light_gbm_spec import V1alpha2LightGBMSpec

# import v1beta1 models into sdk package
from kserve.models.v1beta1_aix_explainer_spec import V1beta1AIXExplainerSpec
from kserve.models.v1beta1_art_explainer_spec import V1beta1ARTExplainerSpec
from kserve.models.v1beta1_alibi_explainer_spec import V1beta1AlibiExplainerSpec
from kserve.models.v1beta1_batcher import V1beta1Batcher
from kserve.models.v1beta1_component_extension_spec import V1beta1ComponentExtensionSpec
from kserve.models.v1beta1_component_status_spec import V1beta1ComponentStatusSpec
from kserve.models.v1beta1_custom_explainer import V1beta1CustomExplainer
from kserve.models.v1beta1_custom_predictor import V1beta1CustomPredictor
from kserve.models.v1beta1_custom_transformer import V1beta1CustomTransformer
from kserve.models.v1beta1_explainer_config import V1beta1ExplainerConfig
from kserve.models.v1beta1_explainer_spec import V1beta1ExplainerSpec
from kserve.models.v1beta1_explainers_config import V1beta1ExplainersConfig
from kserve.models.v1beta1_inference_service import V1beta1InferenceService
from kserve.models.v1beta1_inference_service_list import V1beta1InferenceServiceList
from kserve.models.v1beta1_inference_service_spec import V1beta1InferenceServiceSpec
from kserve.models.v1beta1_inference_service_status import V1beta1InferenceServiceStatus
from kserve.models.v1beta1_inference_services_config import V1beta1InferenceServicesConfig
from kserve.models.v1beta1_ingress_config import V1beta1IngressConfig
from kserve.models.v1beta1_logger_spec import V1beta1LoggerSpec
from kserve.models.v1beta1_onnx_runtime_spec import V1beta1ONNXRuntimeSpec
from kserve.models.v1beta1_pod_spec import V1beta1PodSpec
from kserve.models.v1beta1_predictor_config import V1beta1PredictorConfig
from kserve.models.v1beta1_predictor_extension_spec import V1beta1PredictorExtensionSpec
from kserve.models.v1beta1_predictor_spec import V1beta1PredictorSpec
from kserve.models.v1beta1_predictors_config import V1beta1PredictorsConfig
from kserve.models.v1beta1_sk_learn_spec import V1beta1SKLearnSpec
from kserve.models.v1beta1_pmml_spec import V1beta1PMMLSpec
from kserve.models.v1beta1_tf_serving_spec import V1beta1TFServingSpec
from kserve.models.v1beta1_torch_serve_spec import V1beta1TorchServeSpec
from kserve.models.v1beta1_transformer_config import V1beta1TransformerConfig
from kserve.models.v1beta1_transformer_spec import V1beta1TransformerSpec
from kserve.models.v1beta1_transformers_config import V1beta1TransformersConfig
from kserve.models.v1beta1_triton_spec import V1beta1TritonSpec
from kserve.models.v1beta1_xg_boost_spec import V1beta1XGBoostSpec
from kserve.models.v1beta1_light_gbm_spec import V1beta1LightGBMSpec
from kserve.models.v1beta1_paddle_server_spec import V1beta1PaddleServerSpec

==> kserve-0.8.0.1rc0.tar.gz: kserve-0.8.0.1rc0/kserve/__init__.py <==
# Copyright 2021 The KServe Authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
from __future__ import absolute_import

from kserve.model import Model
from kserve.model_server import ModelServer
from kserve.model_repository import ModelRepository
from kserve.storage import Storage
from kserve.constants import constants
from kserve.utils import utils
from kserve.handlers import base

# import client apis into kserve package
from kserve.api.kserve_client import KServeClient
from kserve.constants import constants

# import ApiClient
from kserve.api_client import ApiClient
from kserve.configuration import Configuration
from kserve.exceptions import OpenApiException
from kserve.exceptions import ApiTypeError
from kserve.exceptions import ApiValueError
from kserve.exceptions import ApiKeyError
from kserve.exceptions import ApiException

# import v1alpha1 models into kserve packages
from kserve.models.v1alpha1_built_in_adapter import V1alpha1BuiltInAdapter
from kserve.models.v1alpha1_cluster_serving_runtime import V1alpha1ClusterServingRuntime
from kserve.models.v1alpha1_cluster_serving_runtime_list import V1alpha1ClusterServingRuntimeList
from kserve.models.v1alpha1_container import V1alpha1Container
from kserve.models.v1alpha1_model_spec import V1alpha1ModelSpec
from kserve.models.v1alpha1_serving_runtime import V1alpha1ServingRuntime
from kserve.models.v1alpha1_serving_runtime_list import V1alpha1ServingRuntimeList
from kserve.models.v1alpha1_serving_runtime_pod_spec import V1alpha1ServingRuntimePodSpec
from kserve.models.v1alpha1_serving_runtime_spec import V1alpha1ServingRuntimeSpec
from kserve.models.v1alpha1_storage_helper import V1alpha1StorageHelper
from kserve.models.v1alpha1_supported_model_format import V1alpha1SupportedModelFormat
from kserve.models.v1alpha1_trained_model import V1alpha1TrainedModel
from kserve.models.v1alpha1_trained_model_list import V1alpha1TrainedModelList
from kserve.models.v1alpha1_trained_model_spec import V1alpha1TrainedModelSpec

# import v1beta1 models into sdk package
from kserve.models.knative_addressable import KnativeAddressable
from kserve.models.knative_condition import KnativeCondition
from kserve.models.knative_url import KnativeURL
from kserve.models.knative_volatile_time import KnativeVolatileTime
from kserve.models.net_url_userinfo import NetUrlUserinfo
from kserve.models.v1beta1_aix_explainer_spec import V1beta1AIXExplainerSpec
from kserve.models.v1beta1_art_explainer_spec import V1beta1ARTExplainerSpec
from kserve.models.v1beta1_alibi_explainer_spec import V1beta1AlibiExplainerSpec
from kserve.models.v1beta1_batcher import V1beta1Batcher
from kserve.models.v1beta1_component_extension_spec import V1beta1ComponentExtensionSpec
from kserve.models.v1beta1_component_status_spec import V1beta1ComponentStatusSpec
from kserve.models.v1beta1_custom_explainer import V1beta1CustomExplainer
from kserve.models.v1beta1_custom_predictor import V1beta1CustomPredictor
from kserve.models.v1beta1_custom_transformer import V1beta1CustomTransformer
from kserve.models.v1beta1_deploy_config import V1beta1DeployConfig
from kserve.models.v1beta1_explainer_config import V1beta1ExplainerConfig
from kserve.models.v1beta1_explainer_extension_spec import V1beta1ExplainerExtensionSpec
from kserve.models.v1beta1_explainer_spec import V1beta1ExplainerSpec
from kserve.models.v1beta1_explainers_config import V1beta1ExplainersConfig
from kserve.models.v1beta1_inference_service import V1beta1InferenceService
from kserve.models.v1beta1_inference_service_list import V1beta1InferenceServiceList
from kserve.models.v1beta1_inference_service_spec import V1beta1InferenceServiceSpec
from kserve.models.v1beta1_inference_service_status import V1beta1InferenceServiceStatus
from kserve.models.v1beta1_inference_services_config import V1beta1InferenceServicesConfig
from kserve.models.v1beta1_ingress_config import V1beta1IngressConfig
from kserve.models.v1beta1_light_gbm_spec import V1beta1LightGBMSpec
from kserve.models.v1beta1_logger_spec import V1beta1LoggerSpec
from kserve.models.v1beta1_model_format import V1beta1ModelFormat
from kserve.models.v1beta1_model_spec import V1beta1ModelSpec
from kserve.models.v1beta1_onnx_runtime_spec import V1beta1ONNXRuntimeSpec
from kserve.models.v1beta1_pmml_spec import V1beta1PMMLSpec
from kserve.models.v1beta1_paddle_server_spec import V1beta1PaddleServerSpec
from kserve.models.v1beta1_pod_spec import V1beta1PodSpec
from kserve.models.v1beta1_predictor_config import V1beta1PredictorConfig
from kserve.models.v1beta1_predictor_extension_spec import V1beta1PredictorExtensionSpec
from kserve.models.v1beta1_predictor_protocols import V1beta1PredictorProtocols
from kserve.models.v1beta1_predictor_spec import V1beta1PredictorSpec
from kserve.models.v1beta1_predictors_config import V1beta1PredictorsConfig
from kserve.models.v1beta1_sk_learn_spec import V1beta1SKLearnSpec
from kserve.models.v1beta1_tf_serving_spec import V1beta1TFServingSpec
from kserve.models.v1beta1_torch_serve_spec import V1beta1TorchServeSpec
from kserve.models.v1beta1_transformer_config import V1beta1TransformerConfig
from kserve.models.v1beta1_transformer_spec import V1beta1TransformerSpec
from kserve.models.v1beta1_transformers_config import V1beta1TransformersConfig
from kserve.models.v1beta1_triton_spec import V1beta1TritonSpec
from kserve.models.v1beta1_xg_boost_spec import V1beta1XGBoostSpec
